@@ -5,7 +5,7 @@ use warnings;
 package Exporter::Almighty;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001001';
+our $VERSION   = '0.001002';
 
 use parent           qw( Exporter::Tiny );
 
@@ -15,15 +15,14 @@ use if $] lt '5.036000', 'builtins::compat' => @builtins;
 use if $] ge '5.036000', 'builtin' => @builtins;
 no if $] ge '5.036000', 'warnings' => qw( experimental::builtin );
 
-use B                qw( perlstring );
-use Carp             qw( croak );
-use Eval::TypeTiny   qw( eval_closure set_subname );
-use Exporter::Tiny   qw( mkopt );
+use B                 qw( perlstring );
+use Carp              qw( croak );
+use Eval::TypeTiny    qw( eval_closure set_subname );
+use Exporter::Tiny    qw( mkopt );
 use Import::Into;
-use Module::Runtime  qw( require_module module_notional_filename );
-use Type::Registry   qw();
-use Type::Tiny::Enum qw();
-use Types::Common    qw(
+use Module::Runtime   qw( require_module module_notional_filename );
+use Type::Registry    qw();
+use Types::Common     qw(
 	-sigs
 	-types
 	assert_Ref       is_Ref
@@ -63,9 +62,13 @@ signature_for setup_for => (
 		NonEmptySimpleStr,
 		Dict[
 			tag    => Optional[HashRef],
-			const  => Optional[HashRef],
-			enum   => Optional[HashRef[ArrayRef]],
 			also   => Optional[ArrayRef],
+			enum   => Optional[HashRef[ArrayRef]],
+			class  => Optional[ArrayRef],
+			role   => Optional[ArrayRef],
+			duck   => Optional[HashRef[ArrayRef]],
+			type   => Optional[ArrayRef],
+			const  => Optional[HashRef],
 		],
 	],
 );
@@ -87,6 +90,10 @@ sub steps {
 	push @steps, 'setup_exporter_for';
 	push @steps, 'setup_reexports_for'            if $setup->{also};
 	push @steps, 'setup_enums_for'                if $setup->{enum};
+	push @steps, 'setup_classes_for'              if $setup->{class};
+	push @steps, 'setup_roles_for'                if $setup->{role};
+	push @steps, 'setup_ducks_for'                if $setup->{duck};
+	push @steps, 'setup_types_for'                if $setup->{type};
 	push @steps, 'setup_constants_for'            if $setup->{const};
 	push @steps, 'finalize_export_variables_for';
 	return @steps;
@@ -138,10 +145,8 @@ sub setup_reexports_for {
 sub setup_enums_for {
 	my ( $me, $into, $setup ) = @_;
 	
-	my ( $into_ISA, undef, undef, $into_EXPORT_TAGS ) =
-		$me->standard_package_variables( $into );
+	require Type::Tiny::Enum;
 	my $reg = Type::Registry->for_class( $into );
-	
 	$me->_ensure_isa_type_library( $into );
 	
 	my %tags = %{ assert_HashRef $setup->{enum} // {} };
@@ -158,6 +163,83 @@ sub setup_enums_for {
 	return;
 }
 
+sub setup_classes_for {
+	my ( $me, $into, $setup ) = @_;
+	require Type::Tiny::Class;
+	$me->_setup_classes_or_roles_for( $into, $setup, 'class', 'Type::Tiny::Class' );
+}
+
+sub setup_roles_for {
+	my ( $me, $into, $setup ) = @_;
+	require Type::Tiny::Role;
+	$me->_setup_classes_or_roles_for( $into, $setup, 'role', 'Type::Tiny::Role' );
+}
+
+sub _setup_classes_or_roles_for {
+	my ( $me, $into, $setup, $kind, $tt_class ) = @_;
+	
+	my $reg = Type::Registry->for_class( $into );
+	$me->_ensure_isa_type_library( $into );
+	
+	my $optlist = mkopt( $setup->{$kind} );
+	for my $dfn ( @$optlist ) {
+		( my $pkg_name  = ( $dfn->[1] //= {} )->{$kind} // $dfn->[0] );
+		( my $type_name = ( $dfn->[1] //= {} )->{name}  // $dfn->[0] ) =~ s/:://g;
+		$tt_class->import( { into => $into }, @$dfn );
+		$into->add_type( $reg->lookup( $type_name ) );
+		eval { require_module( $pkg_name ) };
+	}
+	
+	return;
+}
+
+sub setup_ducks_for {
+	my ( $me, $into, $setup ) = @_;
+	
+	require Type::Tiny::Duck;
+	my $reg = Type::Registry->for_class( $into );
+	$me->_ensure_isa_type_library( $into );
+	
+	my %types = %{ assert_HashRef $setup->{duck} // {} };
+	for my $type_name ( keys %types ) {
+		my $values = $types{$type_name};
+		Type::Tiny::Duck->import( { into => $into }, $type_name, $values );
+		$into->add_type( $reg->lookup( $type_name ) );
+	}
+	
+	return;
+}
+
+sub setup_types_for {
+	my ( $me, $into, $setup ) = @_;
+	
+	my $reg = Type::Registry->for_class( $into );
+	$me->_ensure_isa_type_library( $into );
+	
+	my $optlist = mkopt( $setup->{type} );
+	my @extends = ();
+	for my $dfn ( @$optlist ) {
+		my ( $lib, $list ) = @$dfn;
+		eval { require_module( $lib ) };
+		if ( is_ArrayRef $list ) {
+			for my $type_name ( @$list ) {
+				$into->add_type( $lib->get_type( $type_name ) );
+			}
+		}
+		else {
+			push @extends, $lib;
+		}
+	}
+	
+	if ( @extends ) {
+		require Type::Utils;
+		my $wrapper = eval "sub { package $into; &Type::Utils::extends; }";
+		$wrapper->( @extends );
+	}
+	
+	return;
+}
+
 sub _ensure_isa_type_library {
 	my ( $me, $into ) = @_;
 	return if $into->isa( 'Type::Library' );
@@ -348,6 +430,44 @@ A user of the package defined in the L</SYNOPSIS> could import:
 By convention, the tag names should be snake_case, but constant names
 should be SHOUTING_SNAKE_CASE.
 
+=head3 C<< type >>
+
+This is an arrayref of type libraries. Each library listed will be I<imported>
+into your exporter, and then the types in it will be I<re-exported> to the
+people who use your caller. Each type library can optionally be followed by an
+arrayref of type names if you don't want to just import all types.
+
+  package Your::Package;
+  
+  use Exporter::Almighty -setup => {
+    tags => {
+      foo => [ 'foo1', 'foo2' ],
+    },
+    type => [
+      'Types::Standard',
+      'Types::Common::String' => [ 'NonEmptyStr' ],
+      'Types::Common::String' => [ 'PositiveInt', 'PositiveOrZeroInt' ],
+    ],
+  };
+  
+  sub foo1 { ... }
+  sub foo2 { ... }
+  
+  ...;
+  
+  package main;
+  
+  use Your::Package qw( -foo is_NonEmptyStr );
+  
+  my $got = foo1();
+  if ( is_NonEmptyStr( $got ) ) {
+    foo2();
+  }
+
+If you re-export types like this, then your module will be "promoted" to being
+a subclass of L<Type::Library> instead of L<Exporter::Tiny>. (Type::Library is
+itself a subclass of Exporter::Tiny, so you don't miss out on any features.)
+
 =head3 C<< enum >>
 
 This is a hashref where keys are enumerated type names, and the values are
@@ -371,15 +491,71 @@ A user of the package defined in the L</SYNOPSIS> could import:
   );
   use Your::Package qw( +Status );  # shortcut for the above
 
-The C<< :type >>, C<< :is >>, C<< :assert >>, C<< :to >>, and C<< :constants >>
+The C<Status> function exported by the above will return a L<Type::Tiny::Enum>
+object.
+
+The C<< :types >>, C<< :is >>, C<< :assert >>, C<< :to >>, and C<< :constants >>
 tags will also automatically include the relevent exports.
 
 If you export any enums then your module will be "promoted" from being an
-L<Exporter::Tiny> to being a L<Type::Library> (which is itself a subclass
-of L<Exporter::Tiny>.
+L<Exporter::Tiny> to being a L<Type::Library>.
 
 By convention, enum types should be UpperCamelCase.
 
+=head3 C<< class >>
+
+This is an arrayref of class names.
+
+  use Exporter::Almighty -setup => {
+    class => [
+      'HTTP::Tiny',
+      'LWP::UserAgent',
+    ],
+  };
+
+People can import:
+
+  use Your::Package qw( +HTTPTiny +LWPUserAgent );
+  
+  unless ( is_HTTPTiny($x) or is_LWPUserAgent($x) ) {
+    $x = HTTPTiny->new();
+  }
+
+These create L<Type::Tiny::Class> type constraints similar to how C<enum>
+works. It will similarly promote your exporter to a L<Type::Library>.
+
+Notice that the C<new> method will be proxied through to the underlying
+class, so these can also work as useful aliases for long class names.
+
+  use Exporter::Almighty -setup => {
+    class => [
+      'ShortName' => { class => 'Very::Long::Class::Name' },
+      'TinyName'  => { class => 'An::Even::Longer::Class::Name' },
+    ],
+  };
+
+Exporter::Almighty will attempt to pre-emptively load modules mentioned here,
+so you don't need to do it yourself. However if the modules don't exist, it
+won't complain.
+
+=head3 C<< role >>
+
+This works the same as C<class>, except for roles.
+
+=head3 C<< duck >>
+
+This is a hashref where keys are "duck type" type names, and the values are
+arrayrefs of method names.
+
+  use Exporter::Almighty -setup => {
+    duck => [
+      'UserAgent' => [ 'head', 'get', 'post' ],
+    ],
+  };
+
+These create L<Type::Tiny::Duck> type constraints similar to how C<enum>
+works. It will similarly promote your exporter to be a L<Type::Library>.
+
 =head3 C<< also >>
 
 A list of other packages to also export to your caller. Each package name
